clc;
close all;
clear all;

% This example demonstrates how to implement an UML track to estimate a
% logistic psychometric function.

% psychometric function parameters for the similated observer
phi0 = [10,1.6,0,0];

% intialize the UML track (1-down, 1-up)
uml = UML(exp_config_logit());
uml.setPhi0(phi0);  % configure the simulated observer

uml.par.ndown = 1;
uml.par.mup = 1;

nrevs = 12; % the number of reversals per block
ntrials = 0;  % trials number counter

% Block #1
uml.setX0(25);  % set the initial signal level
while uml.nrev < nrevs 
    ntrials = ntrials + 1;
    
    % present the stimulus and collect the observer's response r in in
    % terms of correct (1) or incorrect (0).
    r = uml.simulateResponse(uml.xnext);
    
    % update the signal level
    uml.update(r);
end

%---------------------------------
% AN INTERUPTION OR BREAK
%
% You can save the UML object and exit your experimental program. To
% resume, load the UML object back.
%---------------------------------

% Block #2
uml.setX0(25);  % set the initial signal level
while uml.nrev < nrevs 
    ntrials = ntrials + 1;
    % present the stimulus and collect the observer's response r in in
    % terms of correct (1) or incorrect (0).
    r = uml.simulateResponse(uml.xnext);
    
    % update the signal level
    uml.update(r);
end

figure;
subplot('position',[0.1 0.7 0.85 0.25],'fontsize',12);
plot(uml.phi(:,1),'k','LineWidth',2);hold;
line([0 ntrials],phi0(1)*ones(1,2),'Color','k','LineStyle','--');
ylabel('\alpha');
axis([0 ntrials uml.par.alpha.limits+[-3 3]]);
set(gca,'XTickLabel',[]);

subplot('position',[0.1 0.4 0.85 0.25],'fontsize',12);
semilogy(uml.phi(:,2),'k','LineWidth',2);hold;
line([0 ntrials],phi0(2)*ones(1,2),'Color','k','LineStyle','--');
ylabel('\beta');
axis([0 ntrials uml.par.beta.limits.*[0.5 2]]);
set(gca,'XTickLabel',[],'YTick',[0.1 1 10]);

subplot('position',[0.1 0.1 0.85 0.25],'fontsize',12);
plot(uml.phi(:,3:4),'LineWidth',2);hold;
line([0 ntrials],phi0(3)*ones(1,2),'Color','k','LineStyle','--');
axis([0 ntrials -0.02 0.22]);
xlabel('Trial number');
ylabel('\gamma / \lambda');